@@ -10,8 +10,7 @@ bool Scanner::doCHECKcommand(Process &child)
     s_firstWord.match(s_firstWord[3]);  // redefine s_firstWord: 1st word
                                         // removed 
 
-    Util::debug() << "running checked command: `" << s_firstWord[0] << "'"
-                                                                    << endl;
+    imsg << "running checked command: `" << s_firstWord[0] << '\'' << endl;
 
     if (Arg::instance().option('n')) // -n (no go) option?
         return true;                    // then indicate by implication that
@@ -21,7 +20,7 @@ bool Scanner::doCHECKcommand(Process &child)
     nextCommand(child,                  // otherwise run the command
                     s_firstWord[0]);
 
-
+    child << flush;
                                         // and return whether there are any
                                         // differences. 
     return sameOutput(logfile, child);
@@ -30,3 +29,4 @@ bool Scanner::doCHECKcommand(Process &child)
 
 
 
+
